@@ -31,5 +31,5 @@ def footprint():
     node_name = platform.node()
     cpu_count = psutil.cpu_count()
     mem_size = psutil.virtual_memory().total
-    cpu_hardware = CpuInfo(Reader())
+    cpu_hardware = CpuInfo(Reader()).hardware()
     return Footprint(node_name, cpu_count, mem_size, cpu_hardware)
\ No newline at end of file
